@@ -148,7 +148,7 @@ class Selenium(Scraper):
             return None
 
     def on_hover(self, path: str, element: any) -> None:
-        element = self.scraper.xPath(element=element, path=path)
+        element = self.xPath(element=element, path=path)
         ActionChains(self.scraper.scraper.driver).move_to_element(element).perform()
 
     def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
